@@ -1,5 +1,5 @@
 package Net::HTTP::Spore::Request;
-$Net::HTTP::Spore::Request::VERSION = '0.08';
+$Net::HTTP::Spore::Request::VERSION = '0.09';
 # ABSTRACT: Net::HTTP::Spore::Request - Portable HTTP request object from SPORE env hash
 
 use Moose;
@@ -168,7 +168,7 @@ sub uri {
         $query_string = $path_info[1] if !$query_string;
     }
 
-    $path_info //= '';
+    $path_info = $path_info // '';
     my $base = $self->_uri_base;
 
     if ( defined $query_string && length($query_string) > 0 ) {
@@ -387,7 +387,7 @@ Net::HTTP::Spore::Request - Net::HTTP::Spore::Request - Portable HTTP request ob
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
